@@ -15,6 +15,7 @@ def update(
     save_statements,
     max_downloads,
     google_sa_credentials,
+    browser,
 ):
     if utility_name == "Kitchener Utilities":
         import utility_bill_scraper.canada.on.kitchener_utilities as ku
@@ -25,9 +26,21 @@ def update(
             data_path=data_path,
             save_statements=save_statements,
             google_sa_credentials=google_sa_credentials,
+            browser=browser,
+        )
+    elif utility_name == "Kitchener-Wilmot Hydro":
+        import utility_bill_scraper.canada.on.kitchener_wilmot_hydro as kwh
+
+        api = kwh.KitchenerWilmotHydroAPI(
+            user,
+            password,
+            data_path=data_path,
+            save_statements=save_statements,
+            google_sa_credentials=google_sa_credentials,
+            browser=browser,
         )
     else:
-        print(f"Unsupported utility: {utility_name}")
+        raise RuntimeError(f"Unsupported utility: {utility_name}")
 
     updates = api.update(max_downloads=max_downloads)
     if updates is not None:
@@ -41,8 +54,12 @@ def export(utility_name, data_path, output, google_sa_credentials):
         import utility_bill_scraper.canada.on.kitchener_utilities as ku
 
         api = ku.KitchenerUtilitiesAPI(data_path=data_path)
+    elif utility_name == "Kitchener-Wilmot Hydro":
+        import utility_bill_scraper.canada.on.kitchener_wilmot_hydro as kwh
+
+        api = kwh.KitchenerWilmotHydroAPI(data_path=data_path)
     else:
-        print(f"Unsupported utility: {utility_name}")
+        raise RuntimeError(f"Unsupported utility: {utility_name}")
 
     df = api.cached_history()
     ext = os.path.splitext(output.lower())[-1]
@@ -76,6 +93,9 @@ def main():
     parser_update.add_argument(
         "-m", "--max-downloads", help="maximum number of statements to download"
     )
+    parser_update.add_argument(
+        "-b", "--browser", help="'Firefox' (default) or 'Chrome'"
+    )
 
     parser_export = subparsers.add_parser("export")
     parser_export.add_argument("-o", "--output", help="export file path")
